@@ -34,10 +34,10 @@ def to_ir_h(ast_nodes, ast_ind, nodes, ast2ir, registers, input_op)
     when :DataNode
       nodes << IR.new(ast_node.token.data_impl, [], ast_node.token)
       ast2ir[ast_ind] = nodes.size - 1
-    when :VirtualDupped0
-      ast2ir[ast_ind] = AstInd.new ast_node.token.dupped_value.args[0]
-    when :VirtualDupped1
-      ast2ir[ast_ind] = AstInd.new ast_node.token.dupped_value.args[1]
+    when :VirtualDuped0
+      ast2ir[ast_ind] = AstInd.new ast_node.token.duped_value.args[0]
+    when :VirtualDuped1
+      ast2ir[ast_ind] = AstInd.new ast_node.token.duped_value.args[1]
     when :ImplicitValue
       ast2ir[ast_ind] = AstInd.new(ast_node.args[0] || ast_node.impl)
     when :IdentityNode
