@@ -1,8 +1,10 @@
 require_relative "./run.rb"
 
 if i=ARGV.index("--")
-  $raw_args = ARGV[i+1..-1]
+  input = ARGV[i+1..-1]
   ARGV[i..-1] = []
+else
+  input = STDIN
 end
 
 if ["-v", "--version"].any?{|option| ARGV.delete(option) }
@@ -18,9 +20,9 @@ begin
   raise IogiiError.new "mustn't give more than one file arg" if ARGV.size > 1
   if ARGV.size == 1
     raise IogiiError.new "file does not exist: %p" % ARGV[0] if !File.file?(ARGV[0])
-    input = IO.binread(ARGV[0])
+    program = IO.binread(ARGV[0])
   end
-  run_and_do_io(input, pretty_print, hs)
+  run_and_do_io(program, input, pretty_print, hs)
 rescue IogiiError => e
   STDERR.puts e.message
 rescue => e
