@@ -5,7 +5,11 @@ require "./run.rb"
 def run(prog, input, pp)
   File.open("prog.iog", "w"){|f| f << prog }
   File.open("input.txt", "w"){|f| f << input }
-  `(ruby main.rb prog.iog -hs #{pp ? "-pp" : ""} > test.hs && runhaskell test.hs < input.txt) 2>&1`
+  if Array === input
+    `(ruby main.rb prog.iog -hs #{pp ? "-pp" : ""} > test.hs && runhaskell test.hs #{input.map{|i|"'"+i+"'"}*" "}) 2>&1`
+  else
+    `(ruby main.rb prog.iog -hs #{pp ? "-pp" : ""} > test.hs && runhaskell test.hs < input.txt) 2>&1`
+  end
 end
 
 tests = ExamplesAndTests
@@ -22,6 +26,7 @@ tests.concat small_tests.filter{|source,expected,from,input,no_pp|
 pass = true
 tests.each{|name, prog, input, expected, pp|
   next if name == "iterate * >" # this ones infinite loop hangs in haskell
+
   found = run(prog, input, pp)
   found.gsub!("test.hs: \e[31mERROR: \e[0m",'ERROR: ')
   found.gsub!(/\nCallStack.*/m,'')
