@@ -1,5 +1,6 @@
 require "./test/collect_tests.rb"
 require "./run.rb"
+require "stringio"
 
 tests = collect_tests
 
@@ -14,22 +15,18 @@ end
 
 puts Header
 puts 'strip = f . f where f = reverse . dropWhile isSpace'
-puts 'iogStdinLines = [[]]'
-puts 'iogAutoInputListEmpty = []'
-puts 'iogAutoInputInt = 777'
+puts 'iogInput = 777'
 puts 'iogMain rawArgs inputIgnored = concat (map (\(a,b,c)-> "found: " ++ strip a ++ " expected: " ++ strip b ++ " from: " ++ c ++ "\n") $ filter (\(a,b,c) -> strip a /= strip b) tests) ++ "\n" ++ show (length tests) ++ " hs tests\n" where
  tests = ['+
 tests.map{|source,expected,from,input,no_pp|
-  $ReadStdin = str_to_lazy_list(input||"").const
-  $ReadStdinLines = read_stdin_lines.const
   size = if expected[/\.\.\./]
     expected = $`
     $`.size
   else
-    100
+    1000
   end
   begin
-    ir3, ir3_ind = gen_graph(source.strip,pp_sep: no_pp ? nil : " ")
+    ir3, ir3_ind = gen_graph(source.strip,StringIO.new(input||""), pp_sep: no_pp ? nil : " ")
     $out = "  (take #{size} (let\n -- %s\n" % (source.lines.map(&:chomp)*";")
     to_hs_main(ir3,ir3_ind)
     $out + ("  ),%p,%p)" % [expected,from]).gsub("\\#","#") # these escapes not valid in haskell
