@@ -17,13 +17,21 @@ File.open("version.rb","w"){|f| f.puts 'Version = "%s"' % version } if version
 File.open("version.rb","w"){|f| f.puts 'Version = "%s+ (unstable)"' % version } if !version && !Version["unstable"]
 
 if version
-  puts 'release checklist'
-  puts '-----------------'
-  puts 'update downloads page'
-  puts 'test/all (regenerates web pages too)'
-  puts 'ruby test/fuzz_test.rb'
-  puts 'view quickref/site'
-  puts 'ruby web/upload.rb'
-  puts 'check version iogii/tgz/site/haskell'
-  puts 'create snapshot, e.g. putweb golfscript.com public_html/iogii/0.2 ../site_uploaded/*'
+  puts 'release checklist
+-----------------
+test/all
+ruby ../run_programs.rb
+ruby ../run_programs_hs.rb
+ruby test/fuzz_test.rb
+ruby test/fuzz_test_hs.rb
+ruby test/test_auto_parse.rb
+clean files manually (ls -lth)
+update docs/source.md page
+ruby web/release 1.1   (put version here)
+ruby web/generate.rb
+view quickref/site
+test online interpreter
+check version number in quickref/#!iogii/tgz/online interpreter/haskell
+ruby web/upload.rb
+create snapshot, e.g. putweb golfscript.com public_html/iogii/0.2 ../site_uploaded/*'
 end
